@@ -1,6 +1,7 @@
 import logging
 import threading
 from typing import List
+from dataclasses import dataclass
 
 from JABWrapper.jab_wrapper import JavaAccessBridgeWrapper
 from JABWrapper.jab_types import JavaObject, AccessibleContextInfo
@@ -16,6 +17,21 @@ from JABWrapper.parsers.table_parser import AccessibleTableParser
 from JABWrapper.parsers.selection_parser import AccessibleSelectionParser
 
 
+@dataclass
+class NodeLocator:
+    name: str
+    description: str
+    role: str
+    states: str
+    indexInParent: int
+    childrenCount: int
+    x: int
+    y: int
+    width: int
+    height: int
+    ancestry: int
+
+
 class ContextNode:
     def __init__(self, jab_wrapper: JavaAccessBridgeWrapper, context: JavaObject, lock, ancestry: int = 0, parse_children=True) -> None:
         self._jab_wrapper = jab_wrapper
@@ -90,22 +106,20 @@ class ContextNode:
         Returns:
             A string that represents the object tree with detailed Node values.
         """
-        string = "{}Role={}, Name={}, VAN={}, Desc={}, St={}, Sts={}, at x={}:y={} w={} h={}; indexInParent={}; cc={}; vcc={}".format(
-            '  ' * self.ancestry,
-            repr(self.context_info.role),
-            repr(self.context_info.name),
-            repr(self.virtual_accessible_name),
-            repr(self.context_info.description),
-            repr(self.state),
-            repr(self.context_info.states),
-            self.context_info.x,
-            self.context_info.y,
-            self.context_info.width,
-            self.context_info.height,
-            self.context_info.indexInParent,
-            self.context_info.childrenCount,
-            self.visible_children_count
-        )
+        string = (f"{'| ' * self.ancestry}"
+                  f"role:{self.context_info.role}; "
+                  f"name:{self.context_info.name}; "
+                  f"virtual_accessible_name:{self.virtual_accessible_name}; "
+                  f"description:{self.context_info.description}; "
+                  f"ancestry:{self.ancestry}; "
+                  f"state:{self.state}; "
+                  f"states:{self.context_info.states}; "
+                  f"at x:{self.context_info.x} y:{self.context_info.y}; "
+                  f"width:{self.context_info.width}; "
+                  f"height:{self.context_info.height}; "
+                  f"indexInParent:{self.context_info.indexInParent}; "
+                  f"childrenCount:{self.context_info.childrenCount}; "
+                  f"visible_children_count:{self.visible_children_count}")
         for parser in self._parsers:
             string += f"{parser}"
         for child in self.children:
@@ -117,25 +131,53 @@ class ContextNode:
         Returns:
             A string of Node values.
         """
-        string = "Role={}, Name={}, VAN={}, Desc={}, St={}, Sts={}, at x={}:y={} w={} h={}; indexInParent={}; cc={}; vcc={}".format(
-            repr(self.context_info.role),
-            repr(self.context_info.name),
-            repr(self.virtual_accessible_name),
-            repr(self.context_info.description),
-            repr(self.state),
-            repr(self.context_info.states),
-            self.context_info.x,
-            self.context_info.y,
-            self.context_info.width,
-            self.context_info.height,
-            self.context_info.indexInParent,
-            self.context_info.childrenCount,
-            self.visible_children_count
-        )
+        string = (f"role:{self.context_info.role}; "
+                  f"name:{self.context_info.name}; "
+                  f"virtual_accessible_name:{self.virtual_accessible_name}; "
+                  f"description:{self.context_info.description}; "
+                  f"ancestry:{self.ancestry}; "
+                  f"state:{self.state}; "
+                  f"states:{self.context_info.states}; "
+                  f"at x:{self.context_info.x} y:{self.context_info.y}; "
+                  f"width:{self.context_info.width}; "
+                  f"height:{self.context_info.height}; "
+                  f"indexInParent:{self.context_info.indexInParent}; "
+                  f"childrenCount:{self.context_info.childrenCount}; "
+                  f"visible_children_count:{self.visible_children_count}")
         for parser in self._parsers:
             string += "{}".format(parser)
         return string
 
+    def get_search_element_tree(self) -> List[NodeLocator]:
+        """
+        Returns node info for all searcheable elements.
+        """
+        nodes = list()
+        nodes.append({
+            "name": self.context_info.name,
+            "description": self.context_info.description,
+            "role": self.context_info.role,
+            "states": self.context_info.states,
+            "indexInParent": self.context_info.indexInParent,
+            "childrenCount": self.context_info.childrenCount,
+            "x": self.context_info.x,
+            "y": self.context_info.y,
+            "width": self.context_info.width,
+            "height": self.context_info.height,
+            "ancestry": self.ancestry
+        })
+        for child in self.children:
+            nodes += child.get_search_element_tree()
+        return nodes
+
+    def traverse(self):
+        yield self
+        for child in self.children:
+            yield from child.traverse()
+
+    def __iter__(self):
+        return self.traverse()
+
     def _get_node_by_context(self, context: JavaObject):
         if self._jab_wrapper.is_same_object(self.context, context):
             return self
@@ -250,12 +292,18 @@ class ContextTree:
         self.root = ContextNode(jab_wrapper, jab_wrapper.context, self._lock)
         self._register_callbacks()
 
+    def __iter__(self):
+        return self.root.traverse()
+
     def __repr__(self) -> str:
         return f"{repr(self.root)}"
 
     def __str__(self):
         return f"{self.root}"
 
+    def get_search_element_tree(self):
+        return self.root.get_search_element_tree()
+
     @retry_callback
     def _property_change_cp(self, source: JavaObject, property: str, old_value: str, new_value: str) -> None:
         with self._lock:
